@@ -18,24 +18,24 @@ class TestPlotFrame(unittest.TestCase):
         self.load_date = datetime(2016, 10, 29, 4)
         self.station = 'GILL'
 
-    def test_rego_load_img_file(self):
+    def test_rego_load_img(self):
         """ Checks that the REGO ASI image file can be loaded. """
-        cdf_obj = load.load_img_file(self.load_date, 'REGO', self.station)
+        cdf_obj = load.load_img(self.load_date, 'REGO', self.station)
         return
 
-    def test_themis_load_img_file(self):
+    def test_themis_load_img(self):
         """ Checks that the REGO ASI image file can be loaded. """
-        cdf_obj = load.load_img_file(self.load_date, 'THEMIS', self.station)
+        cdf_obj = load.load_img(self.load_date, 'THEMIS', self.station)
         return
 
-    def test_rego_load_cal_file(self):
+    def test_rego_load_cal(self):
         """ Load the REGO callibration file. """
-        cal = load.load_cal_file('REGO', self.station)
+        cal = load.load_cal('REGO', self.station)
         return
 
-    def test_themis_load_cal_file(self):
+    def test_themis_load_cal(self):
         """ Load the THEMIS callibration file. """
-        cal = load.load_cal_file('THEMIS', self.station)
+        cal = load.load_cal('THEMIS', self.station)
         return
 
     def test_themis_get_frame(self):
