@@ -4,7 +4,7 @@ from datetime import datetime
 
 import numpy as np
 
-from asilib.utils.project_lla_to_skyfield import lla_to_skyfield
+from asilib.analysis.project_lla_to_skyfield import lla_to_skyfield
 
 """
 Tests that the LLA to AzEl projecting (mapping) returns correct outputs
